@@ -8,13 +8,13 @@ from sanic import Sanic
 
 from web_foundation.config import AppConf
 from web_foundation.extentions.error_handler import ExtendedErrorHandler
-from web_foundation.extentions.realtime.rt_broadcaster import RtBroadcaster
-from web_foundation.extentions.realtime.rt_connection import RtEventCallback
+from web_foundation.extentions.realtime.broadcaster import RtBroadcaster
+from web_foundation.extentions.realtime.connection import RtEventCallback
 from web_foundation.extentions.router import ExtRouter
 from web_foundation.extentions.sanic_ext_worker import ExtWorker
-from web_foundation.kernel.channel import IChannel, IMessage, GenericIMessage
+from web_foundation.kernel.messaging.channel import IChannel, IMessage, GenericIMessage
 from web_foundation.kernel.container import GenericDependencyContainer
-from web_foundation.kernel.dispatcher import IDispatcher, IDispatcherIsolate
+from web_foundation.kernel.messaging.dispatcher import IDispatcher, IDispatcherIsolate
 from web_foundation.kernel.isolate import Isolate
 
 
