@@ -5,12 +5,12 @@ from typing import TypeVar
 from pydantic import BaseSettings
 
 from web_foundation.config import GenericConfig
-from web_foundation.kernel.channel import IChannel
-from web_foundation.kernel.resource import Resource
+from web_foundation.kernel.messaging.channel import IChannel
+from web_foundation.resources.resource import Resource
 from web_foundation.resources.files.interface import FilesResource
 from web_foundation.kernel.dependency import Dependency
 from web_foundation.resources.stores.interface import DataStore
-from web_foundation.services.service import Service
+from web_foundation.kernel.service import Service
 from web_foundation.utils.helpers import in_obj_subclasses, in_obj_classes
 
 
