@@ -2,7 +2,7 @@ import asyncio
 from abc import ABCMeta
 from typing import Dict
 
-from web_foundation.kernel.channel import IChannel
+from web_foundation.kernel.messaging.channel import IChannel
 
 
 class Isolate(metaclass=ABCMeta):
